---
date: 2017-03-20
author: Matthias Günther
email: matthias@wikimatze.de
categories: ruby update
tags: padrino, sinatra, ruby, release
title: Padrino 0.14.0 - cascading option for Rack applications, no ruby default encodings, erubi support, bug fixes
---


## Enable cascading with Rack application

In prior versions of Padrino, the core router would cascade from one application to the next on a 404 response even when the application explicitly specified `cascade: false`. With this release, this has been corrected and Padrino will not cascade even if the specified Rack application returns 404.

```ruby
Padrino.mount('RackApp', cascade: false).to('/api') # this will not be cascaded even if returning 404.
Padrino.mount('PadrinoApp::App', app_file: Padrino.root('app/app.rb')).to('/')
```


## Stop managing Ruby default encodings

Default `Encoding.default_internal` is now `nil` (Ruby default) instead of `UTF-8` (`Padrino < 0.14` default)


## Erubi support

Padrino has now [Erubi support](https://github.com/jeremyevans/erubi "erubi support"). Erubi is a ERB template engine
for Ruby. The most significant changes are:


- Handles postfix conditionals when using escaping (e.g. <%= foo if bar %>)
- Supports frozen_string_literal: true in templates via :freeze option
- Automatically freezes strings for template text when ruby optimizes it (on ruby 2.1+)
- Has 6x faster escaping on ruby 2.3+ by using cgi/escape
- Has 86% smaller memory footprint


More details can be found under [erubi](https://github.com/jeremyevans/erubi#erubi "erubi").


All the credit for the implementation goes to [@adam12](https://github.com/padrino/padrino-framework/pull/2090) - thank
you so much for your hard work.


## Bug Fixes and Miscellaneous Things

There are several bug fixes and other updates:

- Removal of requiring `activesupport` - see [details](https://github.com/padrino/padrino-framework/issues/1971#issuecomment-257792761 "details")
- Removal of `lib` from `$LOAD_PATH` - see [details](https://github.com/padrino/padrino-framework/commit/365f23b5dcf69d72bfab7fb6dcbf4c82fe5d7945 "details")
- FIX [#2105](https://github.com/padrino/padrino-framework/pull/2105) run bundle with `--binstubs` on `-b` switch ([@adam12](https://github.com/adam12))
- FIX [#2097](https://github.com/padrino/padrino-framework/pull/2097) use exe folder for application executables ([@adam12](https://github.com/adam12))
- FIX [#2109](https://github.com/padrino/padrino-framework/pull/2109) change the format of session_id for Padrino Admin AccessControl (thanks [@fnordfish](https://github.com/fnordfish) for reporting this problem)
- FIX [#2111](https://github.com/padrino/padrino-framework/pull/2111) disallow conflicting project names (thanks [@leemour](https://github.com/leemour) for reporting this problem)
- FIX [#2113](https://github.com/padrino/padrino-framework/pull/2113) properly override default values in route definitions if parameter is present ([@fidalgo](https://github.com/fidalgo))
- FIX [#2116](https://github.com/padrino/padrino-framework/pull/2116) fix plugin list `padrino g plugin -l` ([@fnordfish](https://github.com/fnordfish))
- FIX [#2119](https://github.com/padrino/padrino-framework/pull/2119) add rake gem tasks to gem project Rakefile ([@grasp](https://github.com/grasp))
- FIX [#2125](https://github.com/padrino/padrino-framework/pull/2125) do not load in cycle files excluded from reloading (thanks [@fnordfish](https://github.com/fnordfish) for reporting this problem)
- FIX handle nil database passwords for `create_db` and `drop_db` ([@phallstrom](https://github.com/phallstrom))
- FIX lock `rake < 11.0` to avoid `last_comment` error ([@namusyaka](https://github.com/namusyaka))

